@@ -26,7 +26,6 @@
 
 # Don't forget to disbale this :)
 #import pdb
-import pygtk; pygtk.require("2.0")
 import gtk
 import gtk.glade
 import gtk.gdk
@@ -222,7 +221,7 @@ class AppInstall(SimpleGladeApp):
         # Do not show the installed applications filter in installer only mode
         if not self.activation_style.isInstallerOnly:
             filters.extend([("separator", True, "separator", -1),
-                            (_("Installed applications"), False, 
+                            (_("Installed applications only"), False, 
                              _("Show only applications "\
                                "that are installed on your computer"), 
                              SHOW_ONLY_INSTALLED)])
@@ -670,11 +669,11 @@ class AppInstall(SimpleGladeApp):
             body = _("The use of this software may be "
                      "restricted in some countries. You "
                      "must verify that one of the following is true:\n\n"
-                     "• These restrictions do not apply in your country "
+                     "* These restrictions do not apply in your country "
                      "of legal residence\n"
-                     "• You have permission to use this software (for "
+                     "* You have permission to use this software (for "
                      " example, a patent license)\n"
-                     "• You are using this software for research "
+                     "* You are using this software for research "
                      "purposes only")
             dia.set_markup("<big><b>%s</b></big>\n\n%s" % (header,body))
             dia.add_button(_("_Confirm"), gtk.RESPONSE_OK)
@@ -1020,12 +1019,6 @@ class AppInstall(SimpleGladeApp):
     # Main window button callbacks
     # ----------------------------
 
-    def on_button_preferences_clicked(self, widget):
-        if os.path.exists("/usr/bin/software-properties-gtk"):
-            subprocess.Popen(["/usr/bin/gksu", "software-properties-gtk"])
-        elif os.path.exists("/usr/bin/software-properties"):
-            subprocess.Popen(["/usr/bin/gksu", "software-properties"])
-
     def on_button_help_clicked(self, widget):
         subprocess.Popen(["/usr/bin/yelp", "ghelp:gnome-app-install"])
 
