@@ -6,8 +6,6 @@
 #  Sebastian Heinlein
 #
 
-import pygtk
-pygtk.require("2.0")
 import gtk
 import gtk.gdk
 import gobject
@@ -229,10 +227,6 @@ class ApplicationMenu(CoreApplicationMenu):
                 rank += 15
                 trigger += " codec"
                 hit = True
-            if term in item.description.lower():
-                rank += 15
-                trigger += " desc"
-                hit = True
             if self.cache.has_key(item.pkgname) and \
                  term in self.cache[item.pkgname].description.lower():
                 rank += 10
@@ -255,9 +249,13 @@ class ApplicationMenu(CoreApplicationMenu):
 
     def _codecMatch(self, item, term, fuzzy=False):
         #print "_codecMatch for pkg '%s' (term: %s) " % (item.pkgname, term)
+        if ":" in term:
+            term = term.split(":")[1]
         search_cap = gst.caps_from_string(term)
         #print "search_cap: ", search_cap
         for codec in item.codecs:
+            if ":" in codec:
+                codec = codec.split(":")[1]
             if fuzzy and term in codec:
                 return True
             else:
