@@ -1,5 +1,3 @@
-#!/usr/bin/python
-
 # Copyright (C) 2004-2005 Ross Burton <ross@burtonini.com>
 #               2005-2007 Canonical
 #
@@ -21,6 +19,7 @@ import sys
 import gdbm
 import gconf
 import errno
+import gettext
 from gettext import gettext as _
 from optparse import OptionParser
 
@@ -128,7 +127,6 @@ class SearchActivationStyle(ActivationStyle):
     def changesSuccessfulNotify(self): self._changessuccessful = True
     def modifyUserInterface(self, app):
         app.scrolledwindow_left.hide()
-        app.button_preferences.hide()
         app.label_progress.set_markup("<big><b>%s</b></big>\n\n%s" %
                                       (_("Searching for appropriate "
                                          "applications"),
@@ -355,6 +353,10 @@ class XULExtensionsActivationStyle(MimeSearchActivationStyle):
         return True
 
 def main():
+    app="gnome-app-install"
+    gettext.textdomain(app)
+    gettext.bindtextdomain(app)
+
     parser = OptionParser()
     parser.add_option("", "--mime-type",
                       default=None,
@@ -366,7 +368,7 @@ def main():
                       action="store", type="int", dest="transient_for",
                       help="Start as a child window of the given window (Only "
                            "needed by developers")
-    parser.add_option("", "--datadir",
+    parser.add_option("", "--data-dir",
                       default="/usr/share/gnome-app-install",
                       action="store", type="string", dest="datadir",
                       help="Load data from the given directory (Only needed "
